@@ -1,4 +1,4 @@
 from espm.datasets.base import generate_dataset
 from espm.datasets.spim import EDS_espm
 from espm.datasets.built_in_datasets import *
-from espm.datasets import toy
\ No newline at end of file
+from espm.datasets.samples import create_toy_sample 
